from .mock import *

__all__ = (
    "__version__",
    "version_info",
    "Mock",
    "MagicMock",
    "patch",
    "sentinel",
    "DEFAULT",
    "ANY",
    "call",
    "create_autospec",
    "AsyncMock",
    "ThreadingMock",
    "FILTER_DIR",
    "NonCallableMock",
    "NonCallableMagicMock",
    "mock_open",
    "PropertyMock",
    "seal",
)
__version__: str
version_info: tuple[int, int, int]



import sys
from unittest import IsolatedAsyncioTestCase as IsolatedAsyncioTestCase

if sys.version_info >= (3, 10):
    from inspect import iscoroutinefunction as iscoroutinefunction
else:
    from asyncio import iscoroutinefunction as iscoroutinefunction
